@@ -88,7 +88,7 @@ static const char *sm_config_prefix_arg_name G_GNUC_UNUSED = "--sm-config-prefix
 static const char *sm_screen G_GNUC_UNUSED = "--screen";
 #endif
 
-extern void _gnome_ui_gettext_init (gboolean bind_codeset) G_GNUC_INTERNAL;
+G_GNUC_INTERNAL extern void _gnome_ui_gettext_init (gboolean bind_codeset);
 
 /* The master client.  */
 static GnomeClient *master_client= NULL;
@@ -1224,23 +1224,12 @@ gnome_client_disable_master_connection (void)
 }
 #endif /* GNOME_DISABLE_DEPRECATED_SOURCE */
 
-/* Called at exit to ensure the ice connection is closed cleanly
- * This avoids io errors on the session manager side */
-static void
-master_client_clean_up (void)
-{
-  if (master_client && GNOME_CLIENT_CONNECTED (master_client))
-      gnome_client_disconnect (master_client);
-}
-
 static void
 master_client_connect (GnomeClient *client,
 		       gboolean     restarted,
 		       gpointer     client_data)
 {
   gdk_set_sm_client_id (gnome_client_get_id (client));
-
-  g_atexit (master_client_clean_up);
 }
 
 static void
